@@ -89,7 +89,7 @@ repository = %(repository_path)s
       'repository_name': repository_name,
       'repository_path' : repository_path}
     if branch is not None:
-      profile_content += "\nbranch %s" % branch
+      profile_content += "\nbranch = %s" % branch
     custom_profile.write(profile_content)
     custom_profile.close()
   try:
